@@ -118,6 +118,8 @@ ClientGroup:
 
     push_servicepack_and_hotfixes() -- triggers installation of service pack and hotfixes
 
+    repair_software()               -- triggers Repair software on the client group
+
     update_properties()             -- to update the client group properties
 
     add_additional_setting()        -- adds registry key to client group property
@@ -996,7 +998,7 @@ class ClientGroup(object):
                     }]
                 },
                 "clientGroup": {
-                    "newName": self.name
+                    "newName": self.clientgroup_name
                 }
             }
         }
@@ -1016,7 +1018,7 @@ class ClientGroup(object):
                     }]
                 },
                 "clientGroup": {
-                    "newName": self.name
+                    "newName": self.clientgroup_name
                 }
             }
         }
@@ -1180,7 +1182,7 @@ class ClientGroup(object):
                 raise SDKException('ClientGroup', '102', 'No valid clients were found')
 
             output = self._update(
-                clientgroup_name=self.name,
+                clientgroup_name=self.clientgroup_name,
                 clientgroup_description=self.description,
                 associated_clients=validated_clients_list,
                 operation_type=operation_type
@@ -1591,7 +1593,7 @@ class ClientGroup(object):
         """Sets the description of the clientgroup as the value provided in input."""
         if isinstance(value, basestring):
             output = self._update(
-                clientgroup_name=self.name,
+                clientgroup_name=self.clientgroup_name,
                 clientgroup_description=value,
                 associated_clients=self._associated_clients
             )
@@ -1657,7 +1659,7 @@ class ClientGroup(object):
                     if failed to remove all clients from client group
         """
         output = self._update(
-            clientgroup_name=self.name,
+            clientgroup_name=self.clientgroup_name,
             clientgroup_description=self.description,
             associated_clients=self._associated_clients,
             operation_type="CLEAR"
@@ -1752,10 +1754,51 @@ class ClientGroup(object):
         """
         install = Install(self._commcell_object)
         return install.push_servicepack_and_hotfix(
-            client_computer_groups=[self.name],
+            client_computer_groups=[self.clientgroup_name],
             reboot_client=reboot_client,
             run_db_maintenance=run_db_maintenance)
 
+    def repair_software(
+            self,
+            username=None,
+            password=None,
+            reboot_client=False):
+        """triggers Repair software on the client group
+
+        Args:
+             username    (str)               -- username of the machine to re-install features on
+
+                default : None
+
+            password    (str)               -- base64 encoded password
+
+                default : None
+
+            reboot_client (bool)            -- boolean to specify whether to reboot the
+                                                client_group or not
+
+                default: False
+
+        Returns:
+            object - instance of the Job class for this download job
+
+        Raises:
+                SDKException:
+                if install job failed
+
+                if response is empty
+
+                if response is not success
+
+        """
+        install = Install(self._commcell_object)
+        return install.repair_software(
+            client_group=self.clientgroup_name,
+            username=username,
+            password=password,
+            reboot_client=reboot_client
+        )
+
     def update_properties(self, properties_dict):
         """Updates the client group properties
 
@@ -1781,7 +1824,7 @@ class ClientGroup(object):
             "clientGroupOperationType": 2,
             "clientGroupDetail": {
                 "clientGroup": {
-                    "clientGroupName": self.name
+                    "clientGroupName": self.clientgroup_name
                 }
             }
         }
